v2.4.0
======

Features
--------

- Add main module.


v2.3.0
======

Use PEP 420 for namespace.

v2.2.0
======

Refreshed packaging.

v2.1.0
======

Require Python 3.6 or later.

2.0.1
=====

Switch to `pkgutil namespace technique
<https://packaging.python.org/guides/packaging-namespace-packages/#pkgutil-style-namespace-packages>`_
for the ``jaraco`` namespace.

1.6
===

Added ``cmdline.Extend``, an ``argparse.Action`` for use
when nargs is used.

1.5
===

Clean up syntax, configure automatic releases.

1.4
===

Moved hosting to Github.

1.3
===

Add ``.iterate`` to progress bars.

1.2.2
=====

Use ``jaraco.classes`` instead of ``jaraco.meta``, the latter of which was
never released.

1.2.1
=====

Add missing dependency on six.

1.2
===

Adopt ``cmdline`` module from ``jaraco.util``.

1.1
===

Prefer hgtools until setuptools_scm supports older setuptools versions.

1.0
===

Initial release drawn from jaraco.util 10.9.
